import type { IconName } from "../Icon/Icon";
import type { PortalProps } from "../Portal/Portal";
export type BinaryFeedbackOptionType = "positive" | "negative";
export type BinaryFeedbackSize = "s" | "xs";
export type BinaryFeedbackOption = {
    label: string;
    value: string;
    iconName?: IconName;
    tooltipContent?: string;
};
export type BinaryFeedbackOptionProps = BinaryFeedbackOption & {
    name: string;
    checked: boolean;
    type: BinaryFeedbackOptionType;
    iconOnly?: boolean;
    size?: BinaryFeedbackSize;
    onChange: (event: React.ChangeEvent<HTMLInputElement>) => void;
} & Pick<PortalProps, "portalContainer">;
export type BinaryFeedbackProps = {
    /** Name for radio input */
    name: string;
    /**
     * Meta data for positive option
     * @param label - Label for option
     * @param value - Value for option
     * @param iconName - Icon for option (Optional - default "thumbs-up")
     * @param tooltipContent - Additional description to be shown in Tooltip (Optional)
     */
    positiveOption: BinaryFeedbackOption;
    /**
     * Meta data for negative option
     * @param label - Label for option
     * @param value - Value for option
     * @param iconName - Icon for option (Optional - default "thumbs-down")
     * @param tooltipContent - Additional description to be shown in Tooltip (Optional)
     */
    negativeOption: BinaryFeedbackOption;
    /** Current selected value */
    value?: string;
    iconOnly?: boolean;
    size?: BinaryFeedbackSize;
    onChange: (value: string) => void;
    "data-e2e-test-id"?: string;
} & Pick<PortalProps, "portalContainer">;
