import type { FormEvent, ChangeEvent } from "react";
import type { IconName } from "src";
import type { FormFieldGroupProps } from "src/components/Form/FormFieldGroup/FormFieldGroup";
import type { TooltipProps } from "src/components/Tooltip/Tooltip";
export type SegmentedControlOption = {
    name: string;
    label: string;
    value: string;
    displayAsOptionWithSublabel?: boolean;
    disabled?: boolean;
    tooltipContent?: string;
    tooltipPlacement?: TooltipProps["placement"];
    tooltipPortalContainer?: TooltipProps["portalContainer"];
    onClick?: (e: FormEvent<HTMLInputElement>) => void;
    onBlur?: (e: FormEvent<HTMLInputElement>) => void;
    onFocus?: (e: FormEvent<HTMLInputElement>) => void;
    onTooltipVisibilityChange?: TooltipProps["onVisibilityChange"];
} & ({
    iconName?: never;
    sublabel?: string;
    iconOnly?: never;
} | {
    iconName?: IconName;
    sublabel?: never;
    iconOnly?: boolean;
});
export type SegmentedControlProps = {
    options: SegmentedControlOption[];
    /** Current selected value */
    value: string;
    /** Justified layout, with equal size segments spanning to container width */
    justified?: boolean;
    /** Segment size, not applicable on mobile breakpoint */
    size?: "s" | "m" | "l";
    onChange: (value: string) => void;
} & Omit<FormFieldGroupProps, "disabled" | "children">;
export type SegmentedControlOptionProps = Pick<SegmentedControlProps, "size"> & SegmentedControlOption & {
    checked: boolean | undefined;
    isResponsive?: boolean;
    onChange?: (e: ChangeEvent<HTMLInputElement>) => void;
};
