import React from "react";
import type { HorizontalAlignment, SpaceSizes, VerticalAlignment, MQ } from "../../types";
export type InlineProps = {
    id?: string;
    children: React.ReactNode[] | React.ReactElement;
    /** Represents the spacing between the Inline's children.
     * specify [small screen space, medium screen space, large screen space] or one space for all screen sizes
     */
    space?: MQ<SpaceSizes> | SpaceSizes;
    /** Represents the vertical spacing between the Inline's children. It overrides the inherited vertical spacing from `space` if set.
     * specify [small screen space, medium screen space, large screen space] or one space for all screen sizes
     */
    vSpace?: MQ<SpaceSizes> | SpaceSizes;
    /** Represents elements' horizontal alignment
     * specify [small screen alignItems, medium screen alignItems, large screen alignItems] or one alignItems for all screen sizes
     */
    alignItems?: MQ<HorizontalAlignment> | HorizontalAlignment;
    /** Represents elements' vertical alignment
     * specify [small screen vAlignItems, medium screen vAlignItems, large screen vAlignItems] or one vAlignItems for all screen sizes
     */
    vAlignItems?: MQ<VerticalAlignment> | VerticalAlignment;
    /** Set to true to disable wrapping property */
    noWrap?: boolean;
    fullWidth?: boolean;
    /**  render as list */
    as?: "ul" | "ol" | "div";
    "data-e2e-test-id"?: string;
    /** @ignore */
    "data-ds-id"?: string;
};
export declare function Inline({ id, children, alignItems, vAlignItems, space, vSpace, noWrap, fullWidth, as, "data-e2e-test-id": dataE2eTestId, "data-ds-id": dataDsId, }: InlineProps): React.ReactElement;
