import React from "react";
import type { Property } from "csstype";
import type { Hyphens, MediaItemSize, PolymorphicComponentPropsWithRef } from "../../types";
import { type IconName } from "../Icon/Icon";
export type MediaItemProps = {
    src: string;
    title: string;
    /** Display or hide the title underneath the media. */
    showTitle?: boolean;
    /** Pre-defined media sizes. */
    size?: MediaItemSize;
    /** Sets the width of the media if the size is not set. */
    width?: Property.Width;
    /** Sets the height of the media if the size is not set. */
    height?: Property.Height;
    /** Sets the height of the media to equal the width to make it a square. */
    squareByWidth?: boolean;
    /** Sets the object-fit value of the image. */
    fit?: "cover" | "contain";
    categoryLabel?: string;
    categoryIcon?: IconName;
    /** Sets the placement of the category relative to the image.<br/>
     * "inside": only the category icon is required<br/>
     * "outside": both category icon and label are required */
    categoryPlacement?: "inside" | "outside";
    /** Sets the background color behind the media that is visible if the fit is "contain". */
    backgroundColor?: "white" | "black" | "transparent";
    /** Sets the hyphens of the title text. */
    hyphens?: Hyphens;
    /** Sets the active state of the media item. */
    isActive?: boolean;
};
type MediaItemComponent = <C extends React.ElementType = "button">(props: PolymorphicComponentPropsWithRef<C, MediaItemProps>) => React.ReactNode | null;
export declare const MediaItem: MediaItemComponent;
export {};
