import React from "react";
import type { MQ, SpaceSizes } from "../../types";
import type { IconName } from "../Icon/Icon";
/**
 * @param label - The text to display in the tab
 * @param sublabel - A subtext, encased in parentheses
 * @param icon - An icon to display to the left of the label
 * @param as - The element to render the tab as, defaults to `button`
 * @param disabled - Whether the tab is disabled
 * @param tooltipContent - The content of the tooltip to display when the tab is disabled
 */
type Tab = {
    id?: string;
    label: string;
    sublabel?: string;
    icon?: IconName;
    as?: "a" | "button" | React.ElementType;
    disabled?: boolean;
    tooltipContent?: string;
} & Partial<React.ComponentProps<"button">> & Partial<React.ComponentProps<"a">>;
export type TabsProps = {
    /** An array of tabs, contains `header`, `subtitle`, `iconLeft`, `as` (defining the tab as a button or a link) */
    tabs: Tab[];
    children?: React.ReactElement;
    /** The index of the active tab */
    activeTab?: number;
    onTabSelect?: (selectedTab: number) => void;
    tabPanelId?: string;
    /** Horizontal padding space for the tab container, suited for tabs within a Card element */
    horizontalPadding?: SpaceSizes | MQ<SpaceSizes>;
    /** Whether to show a bottom border between tabs and content */
    hideBottomBorder?: boolean;
    "aria-label"?: string;
    "data-e2e-test-id"?: string;
};
export declare function Tabs({ tabs, horizontalPadding, activeTab, children, onTabSelect, tabPanelId, "aria-label": ariaLabel, "data-e2e-test-id": dataE2eTestId, hideBottomBorder, }: TabsProps): React.ReactElement;
export {};
