import type { ReactElement, MouseEvent as ReactMouseEvent } from "react";
import React from "react";
import type { TooltipContentProps } from "../Tooltip/TooltipContent";
type BaseProps = Pick<TooltipContentProps, "placement" | "portalContainer" | "maxWidth" | "contentPadding" | "hideArrow" | "subTheme" | "defaultVerticalPlacement" | "onOverflowViewport"> & {
    name?: string;
    /**  Popover content */
    content: ReactElement;
    "data-e2e-test-id"?: string;
    /**  Programmatically toggle Popover visibility with this prop */
    isVisible?: boolean;
    /**  Called when tooltip appears and disappears */
    onVisibilityChange?: (isVisible: boolean, reason: string) => void;
    /**  Controls whether BasePopover  closes on outside click */
    dismissOnOutsideClick?: boolean;
    /**  Option for focus-trap, controls whether the first focuable item recieves focus */
    disableInitialFocus?: boolean;
    /**  Option for focus-trap, controls whether the trigger should receive back the focus on popover close */
    disableReturnFocusToTrigger?: boolean;
    /**  Render as sheet on mobile web */
    renderAsSheetOnMobile?: boolean;
    /**  Props for configuring the sheet on mobile web */
    sheetProps?: {
        /**  Show the dark scrim backdrop on mobile web when rendering as Sheet */
        hasBackdrop?: boolean;
    };
};
type PopoverChildProps = {
    tabIndex?: number;
    onClick?: (event: ReactMouseEvent) => void;
    [key: string]: any;
};
export type BasePopoverProps = BaseProps & ({
    children: ReactElement<PopoverChildProps>;
    externalTriggerRef?: never;
} | {
    children?: never;
    externalTriggerRef: React.RefObject<HTMLElement>;
});
export declare function BasePopover({ placement, content, children, contentPadding, maxWidth, externalTriggerRef, portalContainer, name, isVisible: isPopoverVisible, dismissOnOutsideClick, "data-e2e-test-id": dataE2eTestId, subTheme, defaultVerticalPlacement, onVisibilityChange, disableInitialFocus, disableReturnFocusToTrigger, renderAsSheetOnMobile, sheetProps, ...restContentProps }: BasePopoverProps): React.ReactElement;
export {};
