import type { AriaAttributes } from "react";
import React from "react";
import type { Property } from "csstype";
import type { SpaceSizes, TextAlignment, MQ } from "../../types";
export type BoxProps = {
    children: React.ReactNode[] | React.ReactNode;
    /** Represents both vertical and horizontal paddings. When used alone, vertical and horizontal paddings will have the same value.
     * Use "vSpace" prop to override vertical padding value in case you want it different.
     * specify [small screen padding, medium screen padding, large screen padding] or one padding for all screen sizes
     * */
    space?: SpaceSizes | MQ<SpaceSizes>;
    /** Represents vertical padding. Used to override the vertical padding from "space" prop.
     * specify [small screen vertical padding, medium screen vertical padding, large screen vertical padding] or one padding for all screen sizes */
    vSpace?: SpaceSizes | MQ<SpaceSizes>;
    /** right padding * */
    rSpace?: SpaceSizes | MQ<SpaceSizes>;
    /** left padding * */
    lSpace?: SpaceSizes | MQ<SpaceSizes>;
    /** top padding * */
    tSpace?: SpaceSizes | MQ<SpaceSizes>;
    /** bottom padding * */
    bSpace?: SpaceSizes | MQ<SpaceSizes>;
    /** Text alignment prop.
     * specify [small screen alignText, medium screen alignText, large screen alignText] or one alignText for all screen sizes */
    alignText?: TextAlignment | MQ<TextAlignment>;
    /** Aria property for assigning an accessible role to an element
     * eg. dialog, tab, tooltip etc. */
    role?: string;
    /** Additional aria attributes. [see documentation](https://github.com/DefinitelyTyped/DefinitelyTyped/blob/02549c083e9d62b604091d770c4568d47282cdd0/types/react/index.d.ts#L1461)
     */
    ariaAttributes?: AriaAttributes;
    id?: string;
    "data-e2e-test-id"?: string;
    height?: Property.Height | MQ<Property.Height>;
};
export declare function Box({ children, space, vSpace, rSpace, lSpace, tSpace, bSpace, alignText, role, ariaAttributes, height, id, "data-e2e-test-id": dataE2eTestId, }: BoxProps): React.ReactElement;
