import type { TextSize, ListSize } from "../../types";
import type { IconProps } from "../Icon/Icon";
import type { CheckboxProps } from "../Form/Checkbox/Checkbox";
export type ListNode = {
    id: string;
    label: string;
    isActive?: boolean;
    description?: string;
    "aria-label"?: string;
    [key: string]: any;
};
export type ActionSizeProps = {
    actionSize: "s" | "m";
};
export type TextSizeProps = {
    textSize?: "s" | "m";
};
type RenderProps = (props: TextSizeProps) => React.ReactNode;
export type ListNodeProps = ListNode & TextSizeProps;
export type EntityListAriaAttributes = {
    ariaLabelExpand?: string;
    ariaLabelCollapse?: string;
};
export type EntityListProps = {
    /**
     * @param ListNode[].id
     * @param ListNode[].label - Label for display
     * @param ListNode[].description - Description bellows the label
     * @param ListNode[].isActive - Hightlight the row
     * @param ListNode[].ariaLabel - Accessibility label
     * @param ListNode[].customProp - Your data in order to use it custom "render" functions
     */
    data: ListNode[];
    size?: ListSize;
    selectedIds?: string[];
    /** Allows selection of items with checkboxes. */
    isSelectable?: boolean;
    onSelectionChange?: (ids: string[]) => void;
    /** It's riggered when a whole list item is clicked. */
    onClick?: (props: ListNodeProps) => void;
    /** Function to get properties for the left-side icon (name and color). */
    getLeftIconProps?: (props: ListNode) => Pick<IconProps, "name" | "color">;
    /** Render content on the right side of the list item. */
    renderRightContent?: (props: ListNodeProps & ActionSizeProps) => React.ReactNode;
    /** Hides the border around the list items. */
    hideBorder?: boolean;
    ariaAttributes?: EntityListAriaAttributes;
    "data-e2e-test-id"?: string;
};
export type EntityListItemWrapperProps = {
    hideBorder: boolean;
    size?: ListSize;
};
export type EntityListItemProps = {
    children?: React.ReactNode;
    checkboxProps?: CheckboxProps;
    description?: string;
    hideBorder?: boolean;
    isActive?: boolean;
    isClickable?: boolean;
    isDisabled?: boolean;
    lSpaceStep?: 0 | 1 | 2 | 3 | 4 | 5;
    onClick?: (e: React.MouseEvent) => void;
    onExpandClick?: (e: React.MouseEvent) => void;
    renderLabel: RenderProps;
    renderLeft?: RenderProps;
    renderRight?: (props: TextSizeProps & ActionSizeProps) => React.ReactNode;
    role?: string;
    size?: ListSize;
    withWrapper?: (content: () => React.ReactNode) => React.ReactNode;
    isExpanded?: boolean;
    isDisabledExpand?: boolean;
    tabIndex?: number;
    onKeyDown?: (e: KeyboardEvent) => void;
    onFocus?: (e: React.FocusEvent) => void;
    ariaLabelExpand?: string;
    ariaLabelCollapse?: string;
    "aria-label": string;
    "aria-level"?: number;
};
export type EntityListItemLabelProps = {
    children: React.ReactNode;
    size: TextSize;
    description?: string;
};
export type SizesForSlots = {
    actionSize: ActionSizeProps["actionSize"];
    textSize: TextSizeProps["textSize"];
};
export {};
