import type { HTMLAttributes, ReactElement } from "react";
import React from "react";
import type { Property } from "csstype";
import type { MQ, SpaceSizes } from "../../types";
import type { GridItemProps } from "./GridItem";
import { GridItem } from "./GridItem";
export type GridProps = {
    /** Define spacing between columns */
    columnGap?: SpaceSizes | MQ<SpaceSizes>;
    /** Define spacing between rows */
    rowGap?: SpaceSizes | MQ<SpaceSizes>;
    /** Define track sizing for explicit grid row tracks, see https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-rows */
    templateRows?: Property.GridTemplateRows | MQ<Property.GridTemplateRows>;
    /** Define track sizing for explicit grid column tracks, see https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-columns
     * Overrides 12 column grid
     */
    templateColumns?: Property.GridTemplateColumns | MQ<Property.GridTemplateColumns>;
    /** Define layout with areas, see https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-areas */
    templateAreas?: Property.GridTemplateAreas | MQ<Property.GridTemplateAreas>;
    /** Define row track size for implicit grid rows, see https://developer.mozilla.org/en-US/docs/Web/CSS/grid-auto-rows */
    autoRows?: Property.GridAutoRows | MQ<Property.GridAutoRows>;
    /** Aligns grid items along the block (column) axis, see https://developer.mozilla.org/en-US/docs/Web/CSS/align-items */
    alignItems?: Property.AlignItems | MQ<Property.AlignItems>;
    /** Aligns grid items along the inline (row) axis, see https://developer.mozilla.org/en-US/docs/Web/CSS/justify-items */
    justifyItems?: Property.JustifyItems | MQ<Property.JustifyItems>;
    /** Displays an inline grid */
    inline?: boolean;
    /** If set to true, it will share parent column tracks */
    isSubgrid?: boolean;
    "data-e2e-test-id"?: string;
    children: ReactElement<GridItemProps>[];
} & HTMLAttributes<HTMLDivElement>;
export declare function Grid({ columnGap, rowGap, "data-e2e-test-id": dataE2eTestId, children, ...rest }: GridProps): React.ReactElement;
export declare namespace Grid {
    var Item: typeof GridItem;
}
