import React from "react";
import type { Theme } from "@emotion/react";
import type { PortalProps } from "../../Portal/Portal";
import type { StackProps } from "../../Stack/Stack";
import type { ButtonGroupButtonProps } from "../ButtonGroup/ButtonGroup";
import type { TextProps } from "../../Typography/Text/Text";
type BaseProps = {
    header?: string;
    onAction?: (action: "cancel" | "action") => void;
    role?: "dialog" | "alertdialog";
    labelHeader?: string;
    /** The black color is going to be replaced with gray one */
    subHeader?: string;
    /** Text and other props for action Button */
    actionButton?: ButtonGroupButtonProps;
    /** Text and other props for action Button */
    secondaryButton?: ButtonGroupButtonProps;
    /** @deprecated Use secondaryButton to pass in text and other props for secondary button */
    cancelButtonLabel?: string;
    /** Aim to use <Modal.Text> and <Modal.Stack> */
    children?: React.ReactNode;
    "data-e2e-test-id"?: string;
    privateProps?: {
        skipPortal?: boolean;
    };
    /** It's a bad pattern to use non-dismissible Modal */
    isDismissible?: boolean;
    isFullScreen?: boolean;
    isMaxWidthLimit?: boolean;
    size?: "m" | "l";
    closeButtonAriaLabel?: string;
    "aria-label"?: string;
    "aria-describedby"?: string;
};
type ConditionalProps = {
    /** Aspect ratio 16:9 */
    imageUrl?: string;
    ImageComponent?: never;
} | {
    imageUrl?: never;
    /** Accept ratio 16:9 */
    ImageComponent?: React.ElementType<any>;
};
export type ModalProps = BaseProps & ConditionalProps & Pick<PortalProps, "portalContainer">;
export declare const StyledBackdrop: import("@emotion/styled").StyledComponent<{
    theme?: Theme;
    as?: React.ElementType;
} & Partial<BaseProps>, React.DetailedHTMLProps<React.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, {}>;
export declare function Modal({ header, subHeader, labelHeader, children, imageUrl, ImageComponent, secondaryButton, cancelButtonLabel, isDismissible, isFullScreen, isMaxWidthLimit, actionButton, role, onAction, size, privateProps: { skipPortal }, portalContainer, closeButtonAriaLabel, "aria-label": ariaLabel, "aria-describedby": ariaDescribedBy, "data-e2e-test-id": dataE2eTestId, }: ModalProps): React.ReactElement;
export declare namespace Modal {
    var Stack: ({ children, ...rest }: Omit<StackProps, "space">) => React.JSX.Element;
    var Text: ({ children, ...rest }: Omit<TextProps, "size" | "variant">) => React.JSX.Element;
}
export {};
