import React from "react";
import type { IconName } from "../Icon/Icon";
export type SecondaryTarget = {
    title: string;
    body?: string;
    link: (props: {
        children: React.ReactNode;
    }) => React.ReactElement;
    "data-e2e-test-id"?: string;
};
export type SecondaryTargetsProps = {
    data: SecondaryTarget[];
};
export type SearchResultProps = {
    /** The result title. Supports some nested HTML tags like <b> and <i>. Text gets clamped after 3 lines. */
    title: string;
    /** The subtitle that accompanies the title. Supports some nested HTML tags like <b> and <i>. Text gets clamped after 3 lines. */
    subtitle?: string;
    /** The primary AMBOSS target. */
    link: (props: {
        children: React.ReactNode;
    }) => React.ReactElement;
    /** The left icon */
    icon?: IconName;
    /** List of details. Supports some nested HTML tags like <b> and <i>. */
    details?: string[];
    /** Usually a text content of the search result. Supports some nested HTML tags like <b> and <i>. Maximum 3 details items allowed where each test gets clamped after 3 lines. */
    body?: string;
    /** List of secondary AMBOSS targets with titles. Text gets clamped after 3 lines. */
    secondaryTargets?: SecondaryTarget[];
    /** List of labels. For example: preclinic, clinic, physician. */
    labels?: string[];
    /** The test id for the result's primary target. */
    "data-e2e-test-id"?: string;
};
export declare function SearchResult({ title, subtitle, icon, details, body, secondaryTargets, link, labels, "data-e2e-test-id": dataE2eTestId, }: SearchResultProps): React.ReactElement;
export declare namespace SearchResult {
    var defaultProps: Partial<SearchResultProps>;
}
