import React from "react";
import type { Property } from "csstype";
import type { StackHorizontalAlignment, MQ, SpaceSizes, StackVerticalAlignment } from "../../types";
export type StackProps = {
    id?: string;
    /** Represents the vertical between the Stack's children
     * specify [small screen space, medium screen space, large screen space] or one space for all screen sizes
     */
    space?: MQ<SpaceSizes> | SpaceSizes;
    /** Represents elements' horizontal alignment
     * specify [small screen alignItems, medium screen alignItems, large screen alignItems] or one alignItems for all screen sizes
     */
    alignItems?: MQ<StackHorizontalAlignment> | StackHorizontalAlignment;
    /**
     * Represents elements' vertical alignment
     * specify [small screen vAlignItems, medium screen vAlignItems, large screen vAlignItems] or one alignItems for all screen sizes
     */
    vAlignItems?: MQ<StackVerticalAlignment> | StackVerticalAlignment;
    /** height */
    height?: Property.Height;
    children: React.ReactNode[] | React.ReactElement;
    /** Render as list */
    as?: "ol" | "ul" | "div";
    "data-e2e-test-id"?: string;
    /** @ignore */
    "data-ds-id"?: string;
};
export declare function Stack({ id, children, space, alignItems, vAlignItems, height, as, "data-e2e-test-id": dataE2eTestId, "data-ds-id": dataDsId, }: StackProps): React.ReactElement;
