import type { ColumnSizes, HorizontalAlignment, MQ, SpaceSizes, TextAlignment, VerticalAlignment, StackHorizontalAlignment, StackVerticalAlignment, Order, ColumnAlignment, Hyphens, BorderRadius } from "../types";
export type Breakpoints = [string, string, string];
type MqProp<T> = [
    T | MQ<T>,
    (Record<T extends string ? T : never, string | number> | ((value: T) => string | number))
];
type MqRules = Record<string, MqProp<TextAlignment> | MqProp<SpaceSizes> | MqProp<HorizontalAlignment> | MqProp<VerticalAlignment> | MqProp<StackHorizontalAlignment> | MqProp<StackVerticalAlignment> | MqProp<ColumnSizes> | MqProp<Order> | MqProp<ColumnAlignment> | MqProp<Hyphens> | MqProp<BorderRadius> | MqProp<boolean>>;
type EmotionCssPropertyName = string;
type EmotionCssValue = string | number;
type EmotionCssDescription = Record<EmotionCssPropertyName, EmotionCssValue>;
type MqFunc = (rules: MqRules | {
    mq: MqRules;
    cq: MqRules;
}) => Record<string, EmotionCssValue | EmotionCssDescription>;
type ResponsiveValueRules = Record<EmotionCssPropertyName, EmotionCssValue[] | EmotionCssValue | MQ<EmotionCssValue>>;
type ResponsiveValueResult = Record<string, EmotionCssValue | EmotionCssDescription>;
export declare const mq: MqFunc;
export declare const useResponsiveStyles: MqFunc;
export declare const mqValue: (rules: ResponsiveValueRules) => ResponsiveValueResult;
export declare const useResponsiveValue: (rules: ResponsiveValueRules) => ResponsiveValueResult;
export {};
